==> ask-sdk-model-0.2.tar.gz: ask-sdk-model-0.2/ask_sdk_model/__init__.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .application import Application
from .context import Context
from .device import Device
from .dialog_state import DialogState
from .directive import Directive
from .intent import Intent
from .intent_confirmation_status import IntentConfirmationStatus
from .intent_request import IntentRequest
from .launch_request import LaunchRequest
from .permissions import Permissions
from .request import Request
from .request_envelope import RequestEnvelope
from .response import Response
from .response_envelope import ResponseEnvelope
from .session import Session
from .session_ended_error import SessionEndedError
from .session_ended_error_type import SessionEndedErrorType
from .session_ended_reason import SessionEndedReason
from .session_ended_request import SessionEndedRequest
from .slot import Slot
from .slot_confirmation_status import SlotConfirmationStatus
from .supported_interfaces import SupportedInterfaces
from .user import User

==> ask-sdk-model-1.22.0.tar.gz: ask-sdk-model-1.22.0/ask_sdk_model/__init__.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .intent_request import IntentRequest
from .permission_status import PermissionStatus
from .application import Application
from .permissions import Permissions
from .slot_confirmation_status import SlotConfirmationStatus
from .connection_completed import ConnectionCompleted
from .slot import Slot
from .task import Task
from .intent_confirmation_status import IntentConfirmationStatus
from .supported_interfaces import SupportedInterfaces
from .session_ended_error import SessionEndedError
from .status import Status
from .response import Response
from .directive import Directive
from .device import Device
from .session_ended_reason import SessionEndedReason
from .user import User
from .scope import Scope
from .dialog_state import DialogState
from .launch_request import LaunchRequest
from .session import Session
from .session_resumed_request import SessionResumedRequest
from .response_envelope import ResponseEnvelope
from .request import Request
from .session_ended_request import SessionEndedRequest
from .context import Context
from .person import Person
from .cause import Cause
from .request_envelope import RequestEnvelope
from .session_ended_error_type import SessionEndedErrorType
from .intent import Intent
